@@ -21,6 +21,7 @@ class Tourn:
     """
 
     import pandas as pd
+    import numpy as np
     import json
     import os
 
@@ -152,7 +153,23 @@ class Tourn:
                 if str(j).strip() in inp:
                     self._sel_estim.append(self._estim[j])
 
-    def run_prel_tournament(self, train_samp=0.7):
+    def _ts_split(self, X_data, y_data, train_samp):
+        # TODO: doc
+        X_data_look = X_data.reset_index()
+        assert "timestamp" in X_data_look.columns, f"timestamp not in columns"
+
+        total_regs = len(X_data_look.index)
+        index_to_look = self.np.floor(total_regs * train_samp)
+        date = X_data_look["timestamp"][index_to_look]
+
+        X_tr = X_data.loc[X_data.index < date]
+        y_tr = y_data.loc[y_data.index < date]
+        X_ts = X_data.loc[X_data.index >= date]
+        y_ts = y_data.loc[y_data.index >= date]
+
+        return X_tr, X_ts, y_tr, y_ts
+
+    def run_prel_tournament(self, train_samp=0.7, mode=None):
         """Run a preliminary tournament with the selected algorithms (default parameters)
         ----------
         parameters:
@@ -167,9 +184,16 @@ class Tourn:
 
         from sklearn.model_selection import train_test_split
 
-        X_tr, X_ts, y_tr, y_ts = train_test_split(
-            self.X_data, self.y_data, train_size=train_samp, random_state=69420
-        )
+        if not mode:
+            X_tr, X_ts, y_tr, y_ts = train_test_split(
+                self.X_data, self.y_data, train_size=train_samp, random_state=69420
+            )
+        elif mode == "ts":
+            X_tr, X_ts, y_tr, y_ts = self._ts_split(
+                self.X_data, self.y_data, train_samp=train_samp
+            )
+        else:
+            raise ValueError(f"mode: {mode} not available")
 
         mod = []
 
@@ -253,6 +277,7 @@ class Tourn:
         folds=3,
         n_jobs=-1,
         train_samp=0.7,
+        mode=None,
     ):
         """run tournament:
         Run the hyperparameter search using GridSearchCV or RandomizedSearchCV.
@@ -365,9 +390,16 @@ class Tourn:
         self.best_estimators = self.pd.DataFrame(best_estimators, columns=col_names)
 
         # Checking overfitting
-        X_tr, X_ts, y_tr, y_ts = train_test_split(
-            self.X_data, self.y_data, train_size=train_samp, random_state=69420
-        )
+        if not mode:
+            X_tr, X_ts, y_tr, y_ts = train_test_split(
+                self.X_data, self.y_data, train_size=train_samp, random_state=69420
+            )
+        elif mode == "ts":
+            X_tr, X_ts, y_tr, y_ts = self._ts_split(
+                self.X_data, self.y_data, train_samp=train_samp
+            )
+        else:
+            raise ValueError(f"mode: {mode} not available")
 
         mod = []
         col_names = ["name", "best_params", "tr_score", "ts_score"]
